@@ -16,8 +16,11 @@ use PHPUnit\Framework\Attributes\BackupStaticProperties;
 use PHPUnit\Framework\Attributes\Before;
 use PHPUnit\Framework\Attributes\BeforeClass;
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\CoversClassesThatExtendClass;
+use PHPUnit\Framework\Attributes\CoversClassesThatImplementInterface;
 use PHPUnit\Framework\Attributes\CoversFunction;
 use PHPUnit\Framework\Attributes\CoversMethod;
+use PHPUnit\Framework\Attributes\CoversNamespace;
 use PHPUnit\Framework\Attributes\CoversNothing;
 use PHPUnit\Framework\Attributes\CoversTrait;
 use PHPUnit\Framework\Attributes\DataProvider;
@@ -40,6 +43,7 @@ use PHPUnit\Framework\Attributes\Medium;
 use PHPUnit\Framework\Attributes\PostCondition;
 use PHPUnit\Framework\Attributes\PreCondition;
 use PHPUnit\Framework\Attributes\PreserveGlobalState;
+use PHPUnit\Framework\Attributes\RequiresEnvironmentVariable;
 use PHPUnit\Framework\Attributes\RequiresFunction;
 use PHPUnit\Framework\Attributes\RequiresMethod;
 use PHPUnit\Framework\Attributes\RequiresOperatingSystem;
@@ -59,12 +63,16 @@ use PHPUnit\Framework\Attributes\TestWith;
 use PHPUnit\Framework\Attributes\TestWithJson;
 use PHPUnit\Framework\Attributes\Ticket;
 use PHPUnit\Framework\Attributes\UsesClass;
+use PHPUnit\Framework\Attributes\UsesClassesThatExtendClass;
+use PHPUnit\Framework\Attributes\UsesClassesThatImplementInterface;
 use PHPUnit\Framework\Attributes\UsesFunction;
 use PHPUnit\Framework\Attributes\UsesMethod;
+use PHPUnit\Framework\Attributes\UsesNamespace;
 use PHPUnit\Framework\Attributes\UsesTrait;
 use PHPUnit\Framework\Attributes\WithoutErrorHandler;
 use PHPUnit\Metadata\DisableReturnValueGenerationForTestDoubles;
 use PHPUnit\Metadata\InvalidAttributeException;
+use PHPUnit\Metadata\WithEnvironmentVariable;
 
 #[CoversClass(AttributeParser::class)]
 #[CoversClass(AfterClass::class)]
@@ -74,8 +82,11 @@ use PHPUnit\Metadata\InvalidAttributeException;
 #[CoversClass(BeforeClass::class)]
 #[CoversClass(Before::class)]
 #[CoversClass(CoversClass::class)]
+#[CoversClass(CoversClassesThatExtendClass::class)]
+#[CoversClass(CoversClassesThatImplementInterface::class)]
 #[CoversClass(CoversFunction::class)]
 #[CoversClass(CoversMethod::class)]
+#[CoversClass(CoversNamespace::class)]
 #[CoversClass(CoversNothing::class)]
 #[CoversClass(CoversTrait::class)]
 #[CoversClass(DataProviderExternal::class)]
@@ -108,6 +119,7 @@ use PHPUnit\Metadata\InvalidAttributeException;
 #[CoversClass(RequiresPhp::class)]
 #[CoversClass(RequiresPhpunit::class)]
 #[CoversClass(RequiresPhpunitExtension::class)]
+#[CoversClass(RequiresEnvironmentVariable::class)]
 #[CoversClass(RequiresSetting::class)]
 #[CoversClass(RunClassInSeparateProcess::class)]
 #[CoversClass(RunInSeparateProcess::class)]
@@ -119,9 +131,13 @@ use PHPUnit\Metadata\InvalidAttributeException;
 #[CoversClass(TestWith::class)]
 #[CoversClass(Ticket::class)]
 #[CoversClass(UsesClass::class)]
+#[CoversClass(UsesClassesThatExtendClass::class)]
+#[CoversClass(UsesClassesThatImplementInterface::class)]
 #[CoversClass(UsesFunction::class)]
 #[CoversClass(UsesMethod::class)]
+#[CoversClass(UsesNamespace::class)]
 #[CoversClass(UsesTrait::class)]
+#[CoversClass(WithEnvironmentVariable::class)]
 #[CoversClass(WithoutErrorHandler::class)]
 #[Small]
 #[Group('metadata')]
