@@ -15,6 +15,7 @@ use PHPUnit\Framework\TestCase;
 use PHPUnit\Metadata\DependsOnClass;
 use PHPUnit\Metadata\DependsOnMethod;
 use PHPUnit\Metadata\InvalidAttributeException;
+use PHPUnit\Metadata\RequiresEnvironmentVariable;
 use PHPUnit\Metadata\RequiresPhp;
 use PHPUnit\Metadata\RequiresPhpExtension;
 use PHPUnit\Metadata\RequiresPhpunit;
@@ -22,9 +23,11 @@ use PHPUnit\Metadata\RequiresPhpunitExtension;
 use PHPUnit\Metadata\RequiresSetting;
 use PHPUnit\Metadata\Version\ComparisonRequirement;
 use PHPUnit\Metadata\Version\ConstraintRequirement;
+use PHPUnit\Metadata\WithEnvironmentVariable;
 use PHPUnit\TestFixture\Metadata\Attribute\AnotherTest;
 use PHPUnit\TestFixture\Metadata\Attribute\BackupGlobalsTest;
 use PHPUnit\TestFixture\Metadata\Attribute\BackupStaticPropertiesTest;
+use PHPUnit\TestFixture\Metadata\Attribute\CoversNothingTest;
 use PHPUnit\TestFixture\Metadata\Attribute\CoversTest;
 use PHPUnit\TestFixture\Metadata\Attribute\DependencyTest;
 use PHPUnit\TestFixture\Metadata\Attribute\DisableReturnValueGenerationForTestDoublesTest;
@@ -44,6 +47,7 @@ use PHPUnit\TestFixture\Metadata\Attribute\NonPhpunitAttributeTest;
 use PHPUnit\TestFixture\Metadata\Attribute\PhpunitAttributeThatDoesNotExistTest;
 use PHPUnit\TestFixture\Metadata\Attribute\PreserveGlobalStateTest;
 use PHPUnit\TestFixture\Metadata\Attribute\ProcessIsolationTest;
+use PHPUnit\TestFixture\Metadata\Attribute\RequiresEnvironmentVariableTest;
 use PHPUnit\TestFixture\Metadata\Attribute\RequiresFunctionTest;
 use PHPUnit\TestFixture\Metadata\Attribute\RequiresMethodTest;
 use PHPUnit\TestFixture\Metadata\Attribute\RequiresOperatingSystemFamilyTest;
@@ -57,6 +61,7 @@ use PHPUnit\TestFixture\Metadata\Attribute\SmallTest;
 use PHPUnit\TestFixture\Metadata\Attribute\TestDoxTest;
 use PHPUnit\TestFixture\Metadata\Attribute\TestWithTest;
 use PHPUnit\TestFixture\Metadata\Attribute\UsesTest;
+use PHPUnit\TestFixture\Metadata\Attribute\WithEnvironmentVariableTest;
 use PHPUnit\TestFixture\Metadata\Attribute\WithoutErrorHandlerTest;
 
 abstract class AttributeParserTestCase extends TestCase
@@ -81,6 +86,16 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertTrue($metadata->asArray()[0]->enabled());
     }
 
+    #[TestDox('Parses #[CoversNamespace] attribute on class')]
+    public function test_parses_CoversNamespace_attribute_on_class(): void
+    {
+        $metadata = $this->parser()->forClass(CoversTest::class)->isCoversNamespace();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isCoversNamespace());
+        $this->assertSame('PHPUnit\TestFixture\Metadata\Attribute', $metadata->asArray()[0]->namespace());
+    }
+
     #[TestDox('Parses #[CoversClass] attribute on class')]
     public function test_parses_CoversClass_attribute_on_class(): void
     {
@@ -91,6 +106,26 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertSame(Example::class, $metadata->asArray()[0]->className());
     }
 
+    #[TestDox('Parses #[CoversClassesThatExtendClass] attribute on class')]
+    public function test_parses_CoversClassesThatExtendClass_attribute_on_class(): void
+    {
+        $metadata = $this->parser()->forClass(CoversTest::class)->isCoversClassesThatExtendClass();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isCoversClassesThatExtendClass());
+        $this->assertSame(Example::class, $metadata->asArray()[0]->className());
+    }
+
+    #[TestDox('Parses #[CoversClassesThatImplementInterface] attribute on class')]
+    public function test_parses_CoversClassesThatImplementInterface_attribute_on_class(): void
+    {
+        $metadata = $this->parser()->forClass(CoversTest::class)->isCoversClassesThatImplementInterface();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isCoversClassesThatImplementInterface());
+        $this->assertSame(Example::class, $metadata->asArray()[0]->interfaceName());
+    }
+
     #[TestDox('Parses #[CoversTrait] attribute on class')]
     public function test_parses_CoversTrait_attribute_on_class(): void
     {
@@ -125,7 +160,7 @@ abstract class AttributeParserTestCase extends TestCase
     #[TestDox('Parses #[CoversNothing] attribute on class')]
     public function test_parses_CoversNothing_attribute_on_class(): void
     {
-        $metadata = $this->parser()->forClass(CoversTest::class)->isCoversNothing();
+        $metadata = $this->parser()->forClass(CoversNothingTest::class)->isCoversNothing();
 
         $this->assertCount(1, $metadata);
         $this->assertTrue($metadata->asArray()[0]->isCoversNothing());
@@ -337,6 +372,37 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertSame('PHPUnit\TestFixture\Metadata\Attribute\SomeExtension', $requirement->extensionClass());
     }
 
+    #[TestDox('Parses #[RequiresEnvironmentVariable] attribute on class')]
+    public function test_parses_RequiresEnvironmentVariable_attribute_on_class(): void
+    {
+        $metadata = $this->parser()->forClass(RequiresEnvironmentVariableTest::class)->isRequiresEnvironmentVariable();
+
+        $this->assertCount(1, $metadata);
+
+        $requirement = $metadata->asArray()[0];
+
+        $this->assertTrue($requirement->isRequiresEnvironmentVariable());
+
+        assert($requirement instanceof RequiresEnvironmentVariable);
+
+        $this->assertSame('foo', $requirement->environmentVariableName());
+        $this->assertSame('bar', $requirement->value());
+    }
+
+    #[TestDox('Parses #[WithEnvironmentVariable] attribute on class')]
+    public function test_parses_WithEnvironmentVariable_attribute_on_class(): void
+    {
+        $metadata = $this->parser()->forClass(WithEnvironmentVariableTest::class)->isWithEnvironmentVariable();
+
+        $this->assertCount(1, $metadata);
+
+        $withEnvironmentVariable = $metadata->asArray()[0];
+        $this->assertTrue($withEnvironmentVariable->isWithEnvironmentVariable());
+        assert($withEnvironmentVariable instanceof WithEnvironmentVariable);
+        $this->assertSame('foo', $withEnvironmentVariable->environmentVariableName());
+        $this->assertSame('bar', $withEnvironmentVariable->value());
+    }
+
     #[TestDox('Parses #[RequiresSetting] attribute on class')]
     public function test_parses_RequiresSetting_attribute_on_class(): void
     {
@@ -402,6 +468,16 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertSame('ticket', $metadata->asArray()[1]->groupName());
     }
 
+    #[TestDox('Parses #[UsesNamespace] attribute on class')]
+    public function test_parses_UsesNamespace_attribute_on_class(): void
+    {
+        $metadata = $this->parser()->forClass(UsesTest::class)->isUsesNamespace();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isUsesNamespace());
+        $this->assertSame('PHPUnit\TestFixture\Metadata\Attribute', $metadata->asArray()[0]->namespace());
+    }
+
     #[TestDox('Parses #[UsesClass] attribute on class')]
     public function test_parses_UsesClass_attribute_on_class(): void
     {
@@ -412,6 +488,26 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertSame(Example::class, $metadata->asArray()[0]->className());
     }
 
+    #[TestDox('Parses #[UsesClassesThatExtendClass] attribute on class')]
+    public function test_parses_UsesClassesThatExtendClass_attribute_on_class(): void
+    {
+        $metadata = $this->parser()->forClass(UsesTest::class)->isUsesClassesThatExtendClass();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isUsesClassesThatExtendClass());
+        $this->assertSame(Example::class, $metadata->asArray()[0]->className());
+    }
+
+    #[TestDox('Parses #[UsesClassesThatImplementInterface] attribute on class')]
+    public function test_parses_UsesClassesThatImplementInterface_attribute_on_class(): void
+    {
+        $metadata = $this->parser()->forClass(UsesTest::class)->isUsesClassesThatImplementInterface();
+
+        $this->assertCount(1, $metadata);
+        $this->assertTrue($metadata->asArray()[0]->isUsesClassesThatImplementInterface());
+        $this->assertSame(Example::class, $metadata->asArray()[0]->interfaceName());
+    }
+
     #[TestDox('Parses #[UsesTrait] attribute on class')]
     public function test_parses_UsesTrait_attribute_on_class(): void
     {
@@ -502,7 +598,7 @@ abstract class AttributeParserTestCase extends TestCase
     #[TestDox('Parses #[CoversNothing] attribute on method')]
     public function test_parses_CoversNothing_attribute_on_method(): void
     {
-        $metadata = $this->parser()->forMethod(CoversTest::class, 'testOne')->isCoversNothing();
+        $metadata = $this->parser()->forMethod(CoversNothingTest::class, 'testOne')->isCoversNothing();
 
         $this->assertCount(1, $metadata);
         $this->assertTrue($metadata->asArray()[0]->isCoversNothing());
@@ -907,6 +1003,46 @@ abstract class AttributeParserTestCase extends TestCase
         $this->assertSame('PHPUnit\TestFixture\Metadata\Attribute\SomeOtherExtension', $requirement->extensionClass());
     }
 
+    #[TestDox('Parses #[RequiresEnvironmentVariable] attribute on method')]
+    public function test_parses_RequiresEnvironmentVariable_attribute_on_method(): void
+    {
+        $metadata = $this->parser()->forMethod(RequiresEnvironmentVariableTest::class, 'testOne')->isRequiresEnvironmentVariable();
+
+        $this->assertCount(2, $metadata);
+
+        $requirement = $metadata->asArray()[0];
+        $this->assertTrue($requirement->isRequiresEnvironmentVariable());
+        assert($requirement instanceof RequiresEnvironmentVariable);
+        $this->assertSame('foo', $requirement->environmentVariableName());
+        $this->assertNull($requirement->value());
+
+        $requirement = $metadata->asArray()[1];
+        $this->assertTrue($requirement->isRequiresEnvironmentVariable());
+        assert($requirement instanceof RequiresEnvironmentVariable);
+        $this->assertSame('bar', $requirement->environmentVariableName());
+        $this->assertSame('baz', $requirement->value());
+    }
+
+    #[TestDox('Parses #[WithEnvironmentVariable] attribute on method')]
+    public function test_parses_WithEnvironmentVariable_attribute_on_method(): void
+    {
+        $metadata = $this->parser()->forMethod(WithEnvironmentVariableTest::class, 'testOne')->isWithEnvironmentVariable();
+
+        $this->assertCount(2, $metadata);
+
+        $withEnvironmentVariable = $metadata->asArray()[0];
+        $this->assertTrue($withEnvironmentVariable->isWithEnvironmentVariable());
+        assert($withEnvironmentVariable instanceof WithEnvironmentVariable);
+        $this->assertSame('foo', $withEnvironmentVariable->environmentVariableName());
+        $this->assertNull($withEnvironmentVariable->value());
+
+        $withEnvironmentVariable = $metadata->asArray()[1];
+        $this->assertTrue($withEnvironmentVariable->isWithEnvironmentVariable());
+        assert($withEnvironmentVariable instanceof WithEnvironmentVariable);
+        $this->assertSame('bar', $withEnvironmentVariable->environmentVariableName());
+        $this->assertSame('baz', $withEnvironmentVariable->value());
+    }
+
     #[TestDox('Parses #[RequiresSetting] attribute on method')]
     public function test_parses_RequiresSetting_attribute_on_method(): void
     {
@@ -1025,7 +1161,6 @@ abstract class AttributeParserTestCase extends TestCase
 
         $this->assertCount(1, $metadata->isCoversClass());
         $this->assertCount(1, $metadata->isCoversFunction());
-        $this->assertCount(2, $metadata->isCoversNothing());
     }
 
     public function test_ignores_attributes_not_owned_by_PHPUnit(): void
