@@ -18,7 +18,7 @@ use function realpath;
 use function sys_get_temp_dir;
 use function uniqid;
 use function unlink;
-use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\CoversNamespace;
 use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\Attributes\Medium;
 use PHPUnit\Framework\TestCase;
@@ -27,7 +27,7 @@ use PHPUnit\TextUI\Configuration\Configuration;
 use SebastianBergmann\CodeCoverage\Report\Html\Colors;
 use SebastianBergmann\CodeCoverage\Report\Thresholds;
 
-#[CoversClass(Loader::class)]
+#[CoversNamespace('PHPUnit\TextUI\XmlConfiguration')]
 #[Medium]
 final class LoaderTest extends TestCase
 {
@@ -262,6 +262,10 @@ final class LoaderTest extends TestCase
         $this->assertTrue($logging->hasJunit());
         $this->assertSame(TEST_FILES_PATH . 'junit.xml', $logging->junit()->target()->path());
 
+        $this->assertTrue($logging->hasOtr());
+        $this->assertSame(TEST_FILES_PATH . 'otr.xml', $logging->otr()->target()->path());
+        $this->assertTrue($logging->otr()->includeGitInformation());
+
         $this->assertTrue($logging->hasTeamCity());
         $this->assertSame(TEST_FILES_PATH . 'teamcity.txt', $logging->teamCity()->target()->path());
 
